@@ -47,8 +47,8 @@ DEFAULTS = {
     'DEFAULT_FIELDSET_TEMPLATE': 'is_core/forms/default_fieldset.html',
     'HEADER_IMAGE': None,
     'ENVIRONMENT': None,
-    'BACKGROUND_EXPORT_TASK_TIME_LIMIT_MINUTES': 90,
-    'BACKGROUND_EXPORT_TASK_SOFT_TIME_LIMIT_MINUTES': 60,
+    'BACKGROUND_EXPORT_TASK_TIME_LIMIT': 60*60,
+    'BACKGROUND_EXPORT_TASK_SOFT_TIME_LIMIT': (60*60) - 5,
     'BACKGROUND_EXPORT_TASK_UPDATE_REQUEST_FUNCTION': None,
     'BACKGROUND_EXPORT_TASK_QUEUE': None,
     'BACKGROUND_EXPORT_SERIALIZATION_LIMIT': 2000,
